import { AbstractMappedComponentDirective, ComponentMapping, MappedComponentProperties } from '../component-mapping';
import { Model } from "@adobe/aem-spa-page-model-manager";
import * as i0 from "@angular/core";
/**
 * Properties corresponding to the AEMContainerComponent
 */
export interface AEMContainerComponentProperties extends MappedComponentProperties {
    componentMapping?: typeof ComponentMapping;
    /**
     * Map of model items included in the current container
     */
    cqItems: {
        [key: string]: Model;
    };
    /**
     * Array of model item keys
     */
    cqItemsOrder: string[];
    /**
     * Class names of the current component
     */
    classNames: string;
}
export declare class AEMContainerComponent extends AbstractMappedComponentDirective implements AEMContainerComponentProperties {
    cqItems: any;
    cqItemsOrder: any;
    classNames: any;
    /**
     * Key of the model structure
     */
    modelName: string;
    /**
     * Returns weather of not we are in the editor
     */
    get isInEditMode(): boolean;
    /**
     * Returns the aggregated path of this container path and the provided path
     *
     * @param path - the provided path to aggregate with the container path
     */
    getDataPath(path: string): string;
    /**
     * Returns the item data from the cqModel
     *
     * @param itemKey - the itemKey to look for in the items.
     */
    getItem(itemKey: string): Model;
    /**
     * Returns the class names of the container based on the data from the cqModel
     */
    getHostClassNames(): string;
    get hostClasses(): string;
    /**
     * Returns the placeholder classes
     */
    getPlaceholderClassNames(): string;
    /**
     * Returns the placeholder path
     */
    get placeholderPath(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<AEMContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AEMContainerComponent, "aem-container", never, { "cqItems": "cqItems"; "cqItemsOrder": "cqItemsOrder"; "classNames": "classNames"; "modelName": "modelName"; }, {}, never, never>;
}
